oslo.messaging
==============

The Oslo messaging API supports RPC and notifications over a number of
different messaging transports.

Contents
========

.. toctree::
   :maxdepth: 1

   transport
   executors
   target
   server
   rpcclient
   notifier
   notification_driver
   notification_listener
   serializer
   exceptions
   opts
   conffixture
   drivers
   supported-messaging-drivers
   AMQP1.0
   pika_driver
   zmq_driver
   driver-dev-guide
   FAQ
   contributing

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

